@@ -98,8 +98,8 @@ class Wrapper:
         '    (hashfunc)%(tp_hash)s,		/* tp_hash */\n' \
         '    (ternaryfunc)%(tp_call)s,		/* tp_call */\n' \
         '    (reprfunc)%(tp_str)s,		/* tp_str */\n' \
-        '    (getattrofunc)0,			/* tp_getattro */\n' \
-        '    (setattrofunc)0,			/* tp_setattro */\n' \
+        '    (getattrofunc)%(tp_getattro)s,	/* tp_getattro */\n' \
+        '    (setattrofunc)%(tp_setattro)s,	/* tp_setattro */\n' \
         '    (PyBufferProcs*)%(tp_as_buffer)s,	/* tp_as_buffer */\n' \
         '    %(tp_flags)s,                      /* tp_flags */\n' \
         '    NULL, 				/* Documentation string */\n' \
@@ -124,7 +124,8 @@ class Wrapper:
         '    (inquiry)%(tp_is_gc)s              /* tp_is_gc */\n' \
         '};\n\n'
 
-    slots_list = ['tp_getattr', 'tp_setattr', 'tp_compare', 'tp_repr',
+    slots_list = ['tp_getattr', 'tp_setattr', 'tp_getattro', 'tp_setattro',
+                  'tp_compare', 'tp_repr',
                   'tp_as_number', 'tp_as_sequence', 'tp_as_mapping', 'tp_hash',
                   'tp_call', 'tp_str', 'tp_as_buffer', 'tp_richcompare', 'tp_iter',
                   'tp_iternext', 'tp_descr_get', 'tp_descr_set', 'tp_init',
@@ -541,24 +542,23 @@ class Wrapper:
             cast_macro = self.objinfo.typecode.replace('_TYPE_', '_', 1)
             funcname = "__%s_class_init" % klass
             self.objinfo.class_init_func = funcname
-            have_implemented_virtuals = not not [True for name, cname in virtuals if cname is not None]
+            have_implemented_virtuals = not not [True for name, cname in virtuals
+                                                          if cname is not None]
             self.fp.write(('\nstatic int\n'
                            '%(funcname)s(gpointer gclass, PyTypeObject *pyclass)\n'
-                           '{\n'
-                           '    PyObject *o;\n') % vars())
+                           '{\n') % vars())
+
             if have_implemented_virtuals:
+                self.fp.write('    PyObject *o;\n')
                 self.fp.write(
                     '    %(klass)sClass *klass = %(class_cast_macro)s(gclass);\n'
                     % vars())
+                
             for name, cname in virtuals:
                 do_name = 'do_' + name
                 if cname is None:
-                    self.fp.write('''
-    if ((o = PyDict_GetItemString(pyclass->tp_dict, "%(do_name)s"))
-        && !PyObject_TypeCheck(o, &PyCFunction_Type)) {
-        PyErr_SetString(PyExc_NotImplementedError, "overriding %(do_name)s is currently not supported");
-        return -1;
-    }\n''' % vars())
+                    self.fp.write('\n    /* overriding %(do_name)s '
+                                  'is currently not supported */\n' % vars())
                 else:
                     self.fp.write('''
     if ((o = PyDict_GetItemString(pyclass->tp_dict, "%(do_name)s"))
